@@ -169,7 +169,7 @@ valopt() {
     local doc="$*"
     if [ $HELP -eq 0 ]
     then
-        local uop=$(echo $op | tr '[:lower:]' '[:upper:]' | tr '\-' '\_')
+        local uop=$(echo $op | tr 'a-z-' 'A-Z_')
         local v="CFG_${uop}"
         eval $v="$default"
         for arg in $CFG_ARGS
@@ -847,7 +847,7 @@ TEMPLATE_PRODUCT_NAME='Rust'
 # rustlib or cargo
 TEMPLATE_REL_MANIFEST_DIR=rustlib
 # 'Rust is ready to roll.' or 'Cargo is cool to cruise.'
-TEMPLATE_SUCCESS_MESSAGE='miri ready to serve.'
+TEMPLATE_SUCCESS_MESSAGE='miri installed.'
 # Locations to look for directories containing legacy, pre-versioned manifests
 TEMPLATE_LEGACY_MANIFEST_DIRS='rustlib,cargo'
 # The installer version
